@@ -94,7 +94,7 @@ pub use crate::{
     error::*,
 };
 
-const MAGIC: [u8; 4] = [99, 130, 83, 99];
+pub const MAGIC: [u8; 4] = [99, 130, 83, 99];
 
 /// default dhcpv4 server port
 pub const SERVER_PORT: u16 = 67;
@@ -220,7 +220,7 @@ impl Message {
         new_chaddr[..len].copy_from_slice(chaddr);
 
         Self {
-            hlen: chaddr.len() as u8,
+            hlen: len as u8,
             xid,
             flags: Flags::default(),
             ciaddr,
@@ -279,10 +279,14 @@ impl Message {
         &self.chaddr[..(self.hlen as usize)]
     }
 
-    /// Set the message's hops.
+    /// Set the message's chaddr. `chaddr` can only up to 16 bytes in length
     pub fn set_chaddr(&mut self, chaddr: &[u8]) -> &mut Self {
         let mut new_chaddr = [0; 16];
-        new_chaddr.copy_from_slice(chaddr);
+        if chaddr.len() >= 16 {
+            new_chaddr.copy_from_slice(&chaddr[..16]);
+        } else {
+            new_chaddr[..chaddr.len()].copy_from_slice(chaddr);
+        }
         self.hlen = chaddr.len() as u8;
         self.chaddr = new_chaddr;
         self
@@ -547,6 +551,20 @@ mod tests {
         Ok(())
     }
 
+    #[test]
+    fn test_set_chaddr() -> Result<()> {
+        let mut msg = Message::new(
+            Ipv4Addr::UNSPECIFIED,
+            Ipv4Addr::UNSPECIFIED,
+            Ipv4Addr::UNSPECIFIED,
+            Ipv4Addr::UNSPECIFIED,
+            &[0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15],
+        );
+        msg.set_chaddr(&[0, 1, 2, 3, 4, 5]);
+        assert_eq!(msg.chaddr().len(), 6);
+        Ok(())
+    }
+
     fn offer() -> Vec<u8> {
         vec![
             0x02, 0x01, 0x06, 0x00, 0x00, 0x00, 0x15, 0x5c, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00,
